%define plugin_root /opt/plugins
%define systemd_config_dir /etc/systemd/system
%define lib_root /opt/monitor/op5/check_vmware
%define config_root /etc/op5/check_vmware
%define service_config %{config_root}/service.cfg
%define gunicorn_config %{config_root}/gunicorn.cfg
%define gunicorn_pidfile /var/run/check_vmware.pid
%define gunicorn_logfile /var/log/op5/check_vmware.log

%define real_name check_vmware
%define executable_name check_vmware_v2

Summary: Monitor plugin for running VMware checks
Name: naemon-check-vmware
Version: %{op5version}
Release: %{op5release}%{?dist}
URL: http://www.op5.se
Vendor: OP5 AB
License: GPLv2
Group: Applications/Internet

Source: %{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}

Requires: bash, redis, python34

%if 0%{?el6}
%description
Monitor plugin for running VMware checks.

The plugin has a service that runs in the background to avoid making a new
HTTP connection to VMware for every check. Before starting the service you
also need to start Redis. Run the commands `service redis start` and
`service check_vmware start`.

For more information about installing and running the plugin, see the README
file.
%else
%description
Monitor plugin for running VMware checks.

The plugin has a service that runs in the background to avoid making a new
HTTP connection to vmware for every check. Before starting the service you
also need to start Redis. Run the commands `systemctl start redis` followed
by `systemctl start check_vmware`. To make sure the services start after a
system reboot, you also need to enable them by running the commands
`systemctl enable redis` and `systemctl enable check_vmware`.

For more information about installing and running the plugin, see the README
file.
%endif

%prep
%setup -q

%if 0%{?el6}
%{__cat} <<EOF >check_vmware.init
#!/bin/sh
#
# Start and stop op5 check_vmware service
#
# chkconfig: 235 95 05
#
### BEGIN INIT INFO
# Provides: check_vmware
# Required-Start: \$local_fs \$remote_fs \$syslog \$network
# Required-Stop: \$local_fs \$remote_fs \$syslog \$network
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Short-Description: Start and stop op5 check_vmware service
### END INIT INFO

# Source function library.
. /etc/rc.d/init.d/functions

prog=check_vmware

start() {
    echo -n \$"Starting \$prog: "
    cd %{lib_root}
    daemon sh launch-service.sh
    RETVAL=\$?
    echo
    return \$RETVAL
}

stop() {
    echo -n \$"Stopping \$prog: "
    killproc -p %{gunicorn_pidfile} \${prog} -QUIT
    RETVAL=\$?
    echo
    [ \$RETVAL = 0 ] && rm -f %{gunicorn_pidfile}
}

rh_status() {
    status -p /var/run/check_vmware.pid \${prog}
}

rh_status_q() {
    rh_status >/dev/null 2>&1
}

case "\$1" in
    start)
        rh_status_q && rh_status && exit 0
        start
        ;;
    stop)
        rh_status_q || rh_status || exit 0
        stop
        ;;
    restart)
        stop
        start
        ;;
    condrestart)
        rh_status_q || exit 0
        stop
        start
        ;;
    status)
        rh_status
        ;;
    *)
        echo \$"Usage: \$0 {start|stop|status|restart}"
        exit 2
esac
exit \$?
EOF
%else
%{__cat} <<EOF >check_vmware.service
[Unit]
Description=Monitor VMware plugin service
After=multi-user.target
Wants=redis.service

[Service]
User=root
Group=root
WorkingDirectory=%{lib_root}
ExecStart=/usr/bin/sh launch-service.sh
Restart=always

[Install]
WantedBy=multi-user.target
EOF
%endif

%{__cat} <<EOF >launch-service.sh
#!/usr/bin/env bash
%if 0%{?el6}
CHECK_VMWARE_CONFIG="%{service_config}" %{lib_root}/venv/bin/gunicorn --config %{gunicorn_config} --pid %{gunicorn_pidfile} --log-file %{gunicorn_logfile} --capture-output --daemon check_vmware.service.wsgi:app
%else
CHECK_VMWARE_CONFIG="%{service_config}" %{lib_root}/venv/bin/gunicorn --config %{gunicorn_config} --pid %{gunicorn_pidfile} check_vmware.service.wsgi:app
%endif
EOF

%{__cat} <<EOF >check_vmware_script
#!/usr/bin/env bash
# This check command requires a unicode aware environment, so we will force the
# LC_ALL variable to en_US.UTF-8 if necessary. See this URL for more info:
# http://click.pocoo.org/5/python3/#python-3-surrogate-handling
tmp_lc_all=\`locale -k LC_CTYPE | grep -qiE 'charmap="utf-?8"' && echo \$LC_ALL || echo "en_US.UTF-8"\`
LC_ALL=\$tmp_lc_all %{lib_root}/venv/bin/check_vmware_v2 "\$@"
EOF

%{__cat} <<EOF >gunicorn.cfg
"""
See http://docs.gunicorn.org/en/stable/settings.html for documentation on the available
Gunicorn configuration.
"""

bind = 'localhost:8000'
workers = 2
EOF

%{__cat} <<EOF >service.cfg
"""
See README.md for documentation on the available Check VMware service config.

See http://flask.pocoo.org/docs/0.12/config/ for documentation on the available
Flask configuration.

See http://pythonhosted.org/Flask-Caching/#configuring-flask-caching for
documentation on the available Flask-Caching configuration.
"""

EOF
# Magic line to copy existing defaults from config.py, commented.
%{__awk} '/^#/ { f = 1 } f' check_vmware/service/config.py | %{__awk} '/^[A-Za-z_]/ {print "#" $0; next} 1' >>service.cfg

%install
%{__rm} -rf %{buildroot}
%{__mkdir} -p %{buildroot}%{lib_root}
%{__mkdir} -p %{buildroot}%{config_root}
%{__cp} -R check_vmware %{buildroot}%{lib_root}/check_vmware
%{__cp} -R vsan_sdk %{buildroot}%{lib_root}/vsan_sdk
%{__install} -Dp -m0644 check_vmware.metadata %{buildroot}%{plugin_root}/metadata/%{executable_name}.metadata
%{__install} -Dp -m0755 launch-service.sh %{buildroot}%{lib_root}/launch-service.sh
%{__install} -Dp -m0644 README.md %{buildroot}%{lib_root}/README.md
%{__install} -Dp -m0644 LICENSE.txt %{buildroot}%{lib_root}/LICENSE.txt
%{__install} -Dp -m0644 Pipfile %{buildroot}%{lib_root}/Pipfile
%{__install} -Dp -m0644 Pipfile.lock %{buildroot}%{lib_root}/Pipfile.lock
%{__install} -Dp -m0755 setup.py %{buildroot}%{lib_root}/setup.py
%{__install} -Dp -m0644 MANIFEST.in %{buildroot}%{lib_root}/MANIFEST.in
%{__install} -Dp -m0755 check_vmware_script %{buildroot}%{plugin_root}/%{executable_name}
%{__install} -Dp -m0644 gunicorn.cfg %{buildroot}%{config_root}/gunicorn.cfg
%{__install} -Dp -m0644 service.cfg %{buildroot}%{config_root}/service.cfg
%if 0%{?el6}
%{__install} -Dp -m0755 check_vmware.init %{buildroot}%{_sysconfdir}/init.d/check_vmware
%else
%{__install} -Dp -m0644 check_vmware.service %{buildroot}%{systemd_config_dir}/check_vmware.service
%endif

%post
cd %{lib_root}
python3.4 -m venv venv
source venv/bin/activate
pip install --upgrade pip setuptools
pip install --upgrade pipenv
pipenv sync --bare --sequential
pip install .

%postun
%if 0%{?el6}
if [ "$1" -ge "1" ] ; then
    /sbin/service check_vmware condrestart >/dev/null 2>&1 || :
fi
%else
%systemd_postun_with_restart check_vmware.service
%endif

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc %{lib_root}/README.md
%doc %{lib_root}/LICENSE.txt
%{plugin_root}/%{executable_name}
%{lib_root}/check_vmware
%{lib_root}/vsan_sdk
%{lib_root}/launch-service.sh
%{lib_root}/setup.py
%{lib_root}/MANIFEST.in
%{lib_root}/Pipfile
%{lib_root}/Pipfile.lock
%if 0%{?el6}
%config(noreplace) %{_sysconfdir}/init.d/check_vmware
%else
%config(noreplace) %{systemd_config_dir}/check_vmware.service
%endif
%config(noreplace) %{plugin_root}/metadata/%{executable_name}.metadata
%config(noreplace) %{config_root}
%exclude %{lib_root}/setup.pyc
%exclude %{lib_root}/setup.pyo

%changelog
* Tue Jul 10 2018 Petter Nyström <support@op5.com> - v0.1.10
- Install config files under /etc/op5/check_vmware
* Mon Jul 9 2018 Petter Nyström <support@op5.com> - v0.1.9
- Use python3.4 on both EL6 and EL7
* Thu Jun 28 2018 Petter Nyström <support@op5.com> - v0.1.8
- Add LICENSE.txt file
* Tue Mar 6 2018 Petter Nyström <support@op5.com> - v0.1.5
- Use pipenv to sync version dependencies
* Thu Mar 1 2018 Petter Nyström <support@op5.com> - v0.1.5
- Use config(noreplace) macro instead of config
* Tue Feb 13 2018 Petter Nyström <support@op5.com> - v0.0.10
- Install init script in /etc/init.d/ instead of /etc/init
* Tue Jan 16 2018 Petter Nyström <support@op5.com> - v0.0.6
- Install check_vmware command
* Mon Jan 8 2018 Erik Mellegård <support@op5.com> - v0.0.4
- Add project to CI pipeline (needs some tweaking)
* Mon Jan 8 2018 Erik Mellegård <support@op5.com> - v0.0.3
- Add plugin metadata file. Add requirements. Set 2 workers as default for service.
* Thu Jan 4 2018 Erik Mellegård <support@op5.com> - v0.0.2
- Add shell script that calls virtualenv python executable, so that help text in monitor displays correct help text
* Tue Jan 2 2018 Erik Mellegård <support@op5.com> - v0.0.1
- Initial attempt.
